@@ -1,11 +1,11 @@
 #
-# $Id: Routing.pm,v 51897565ff32 2015/02/09 20:41:56 gomor $
+# $Id: Routing.pm,v d41bb6f393f9 2015/02/19 06:26:41 gomor $
 #
 package Net::Routing;
 use strict;
 use warnings;
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 use base qw(Class::Gomor::Hash);
 
@@ -189,10 +189,11 @@ sub get {
          if ($route->{route}
          &&  $route->{route} ne NR_DEFAULT_ROUTE4()
          &&  $route->{route} ne NR_DEFAULT_ROUTE6()) {
+            my $r;
             eval {
-               Net::CIDR::cidrlookup($target, $route->{route});
+               $r = Net::CIDR::cidrlookup($target, $route->{route});
             };
-            if (! $@) {
+            if (! $@ && $r) {
                push @routes, $route;
             }
          }
